[jboss-cvs] JBossAS SVN: r87824 - in projects/jboss-osgi/trunk: bundle and 9 other directories.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Fri Apr 24 13:35:41 EDT 2009


Author: thomas.diesler at jboss.com
Date: 2009-04-24 13:35:41 -0400 (Fri, 24 Apr 2009)
New Revision: 87824

Modified:
   projects/jboss-osgi/trunk/bundle/pom.xml
   projects/jboss-osgi/trunk/microcontainer/osgi-int/pom.xml
   projects/jboss-osgi/trunk/pom.xml
   projects/jboss-osgi/trunk/runtime/equinox/pom.xml
   projects/jboss-osgi/trunk/runtime/felix/pom.xml
   projects/jboss-osgi/trunk/runtime/felix/src/main/java/org/jboss/osgi/felix/framework/FelixIntegration.java
   projects/jboss-osgi/trunk/runtime/knopflerfish/pom.xml
   projects/jboss-osgi/trunk/spi/src/main/java/org/jboss/osgi/spi/internal/MicrocontainerBootstrapProvider.java
   projects/jboss-osgi/trunk/testsuite/example/pom.xml
   projects/jboss-osgi/trunk/testsuite/functional/pom.xml
   projects/jboss-osgi/trunk/testsuite/pom.xml
Log:
Start blueprint prototyping

Modified: projects/jboss-osgi/trunk/bundle/pom.xml
===================================================================
--- projects/jboss-osgi/trunk/bundle/pom.xml	2009-04-24 17:35:14 UTC (rev 87823)
+++ projects/jboss-osgi/trunk/bundle/pom.xml	2009-04-24 17:35:41 UTC (rev 87824)
@@ -14,6 +14,7 @@
   <!-- Modules -->
   <modules>
     <module>common</module>
+    <module>blueprint</module>
     <module>logging</module>
     <module>remotelog</module>
     <module>webconsole</module>

Modified: projects/jboss-osgi/trunk/microcontainer/osgi-int/pom.xml
===================================================================
--- projects/jboss-osgi/trunk/microcontainer/osgi-int/pom.xml	2009-04-24 17:35:14 UTC (rev 87823)
+++ projects/jboss-osgi/trunk/microcontainer/osgi-int/pom.xml	2009-04-24 17:35:41 UTC (rev 87824)
@@ -102,11 +102,6 @@
       <artifactId>jboss-deployers-impl</artifactId>
        <scope>test</scope>
     </dependency>
-     <dependency>
-        <groupId>junit</groupId>
-        <artifactId>junit</artifactId>
-        <scope>test</scope>
-     </dependency>
   </dependencies>
   
   <build>

Modified: projects/jboss-osgi/trunk/pom.xml
===================================================================
--- projects/jboss-osgi/trunk/pom.xml	2009-04-24 17:35:14 UTC (rev 87823)
+++ projects/jboss-osgi/trunk/pom.xml	2009-04-24 17:35:41 UTC (rev 87824)
@@ -268,6 +268,20 @@
     </dependencies>
   </dependencyManagement>
 
+  <!-- Dependencies -->  
+  <dependencies>
+    <dependency>
+      <groupId>junit</groupId>
+      <artifactId>junit</artifactId>
+      <scope>test</scope>
+    </dependency>
+    <dependency>
+      <groupId>org.jboss.logging</groupId>
+      <artifactId>jboss-logging-log4j</artifactId>
+      <scope>test</scope>
+    </dependency>
+  </dependencies>
+
   <build>
 
     <!-- Plugins -->

Modified: projects/jboss-osgi/trunk/runtime/equinox/pom.xml
===================================================================
--- projects/jboss-osgi/trunk/runtime/equinox/pom.xml	2009-04-24 17:35:14 UTC (rev 87823)
+++ projects/jboss-osgi/trunk/runtime/equinox/pom.xml	2009-04-24 17:35:41 UTC (rev 87824)
@@ -39,18 +39,6 @@
       <groupId>org.eclipse.equinox</groupId>
       <artifactId>org.eclipse.osgi.services</artifactId>
     </dependency>
-
-    <!-- Test Dependencies -->
-    <dependency>
-      <groupId>junit</groupId>
-      <artifactId>junit</artifactId>
-      <scope>test</scope>
-    </dependency>
-    <dependency>
-      <groupId>org.jboss.logging</groupId>
-      <artifactId>jboss-logging-log4j</artifactId>
-      <scope>test</scope>
-    </dependency>
   </dependencies>
 
   <!-- Build -->

Modified: projects/jboss-osgi/trunk/runtime/felix/pom.xml
===================================================================
--- projects/jboss-osgi/trunk/runtime/felix/pom.xml	2009-04-24 17:35:14 UTC (rev 87823)
+++ projects/jboss-osgi/trunk/runtime/felix/pom.xml	2009-04-24 17:35:41 UTC (rev 87824)
@@ -40,18 +40,6 @@
       <artifactId>org.apache.felix.log</artifactId>
       <scope>provided</scope>
     </dependency>
-
-    <!-- Test Dependencies -->
-    <dependency>
-      <groupId>junit</groupId>
-      <artifactId>junit</artifactId>
-      <scope>test</scope>
-    </dependency>
-    <dependency>
-      <groupId>org.jboss.logging</groupId>
-      <artifactId>jboss-logging-log4j</artifactId>
-      <scope>test</scope>
-    </dependency>
   </dependencies>
 
   <!-- Build -->

Modified: projects/jboss-osgi/trunk/runtime/felix/src/main/java/org/jboss/osgi/felix/framework/FelixIntegration.java
===================================================================
--- projects/jboss-osgi/trunk/runtime/felix/src/main/java/org/jboss/osgi/felix/framework/FelixIntegration.java	2009-04-24 17:35:14 UTC (rev 87823)
+++ projects/jboss-osgi/trunk/runtime/felix/src/main/java/org/jboss/osgi/felix/framework/FelixIntegration.java	2009-04-24 17:35:41 UTC (rev 87824)
@@ -112,6 +112,10 @@
 
    public void start()
    {
+      // Create the Felix instance
+      if (framework == null)
+         create();
+      
       // Start the System Bundle
       try
       {

Modified: projects/jboss-osgi/trunk/runtime/knopflerfish/pom.xml
===================================================================
--- projects/jboss-osgi/trunk/runtime/knopflerfish/pom.xml	2009-04-24 17:35:14 UTC (rev 87823)
+++ projects/jboss-osgi/trunk/runtime/knopflerfish/pom.xml	2009-04-24 17:35:41 UTC (rev 87824)
@@ -39,18 +39,6 @@
       <groupId>org.osgi</groupId>
       <artifactId>org.osgi.compendium</artifactId>
     </dependency>
-
-    <!-- Test Dependencies -->
-    <dependency>
-      <groupId>junit</groupId>
-      <artifactId>junit</artifactId>
-      <scope>test</scope>
-    </dependency>
-    <dependency>
-      <groupId>org.jboss.logging</groupId>
-      <artifactId>jboss-logging-log4j</artifactId>
-      <scope>test</scope>
-    </dependency>
   </dependencies>
 
   <!-- Build -->

Modified: projects/jboss-osgi/trunk/spi/src/main/java/org/jboss/osgi/spi/internal/MicrocontainerBootstrapProvider.java
===================================================================
--- projects/jboss-osgi/trunk/testsuite/example/pom.xml	2009-04-24 17:35:14 UTC (rev 87823)
+++ projects/jboss-osgi/trunk/testsuite/example/pom.xml	2009-04-24 17:35:41 UTC (rev 87824)
@@ -73,18 +73,6 @@
       <version>${version}</version>
       <scope>provided</scope>
     </dependency>
-
-    <!-- Test Dependencies -->
-    <dependency>
-      <groupId>junit</groupId>
-      <artifactId>junit</artifactId>
-      <scope>test</scope>
-    </dependency>
-    <dependency>
-      <groupId>org.jboss.logging</groupId>
-      <artifactId>jboss-logging-log4j</artifactId>
-      <scope>test</scope>
-    </dependency>
   </dependencies>
 
   <!-- Build -->

Modified: projects/jboss-osgi/trunk/testsuite/functional/pom.xml
===================================================================
--- projects/jboss-osgi/trunk/testsuite/functional/pom.xml	2009-04-24 17:35:14 UTC (rev 87823)
+++ projects/jboss-osgi/trunk/testsuite/functional/pom.xml	2009-04-24 17:35:41 UTC (rev 87824)
@@ -73,18 +73,6 @@
       <version>${version}</version>
       <scope>provided</scope>
     </dependency>
-
-    <!-- Test Dependencies -->
-    <dependency>
-      <groupId>junit</groupId>
-      <artifactId>junit</artifactId>
-      <scope>test</scope>
-    </dependency>
-    <dependency>
-      <groupId>org.jboss.logging</groupId>
-      <artifactId>jboss-logging-log4j</artifactId>
-      <scope>test</scope>
-    </dependency>
   </dependencies>
 
   <!-- Build -->

Modified: projects/jboss-osgi/trunk/testsuite/pom.xml
===================================================================
--- projects/jboss-osgi/trunk/testsuite/pom.xml	2009-04-24 17:35:14 UTC (rev 87823)
+++ projects/jboss-osgi/trunk/testsuite/pom.xml	2009-04-24 17:35:41 UTC (rev 87824)
@@ -56,7 +56,7 @@
                   <value>${basedir}/target</value>
                 </property>
                 <property>
-                  <name>org.jboss.osgi.default.framework.beans</name>
+                  <name>jboss.osgi.framework.config</name>
                   <value>jboss-osgi-felix-beans.xml</value>
                 </property>
               </systemProperties>
@@ -100,7 +100,7 @@
                   <value>${basedir}/target</value>
                 </property>
                 <property>
-                  <name>org.jboss.osgi.default.framework.beans</name>
+                  <name>jboss.osgi.framework.config</name>
                   <value>jboss-osgi-felix-beans.xml</value>
                 </property>
               </systemProperties>
@@ -145,7 +145,7 @@
                   <value>${basedir}/target</value>
                 </property>
                 <property>
-                  <name>org.jboss.osgi.default.framework.beans</name>
+                  <name>jboss.osgi.framework.config</name>
                   <value>jboss-osgi-equinox-beans.xml</value>
                 </property>
               </systemProperties>
@@ -190,7 +190,7 @@
                   <value>${basedir}/target</value>
                 </property>
                 <property>
-                  <name>org.jboss.osgi.default.framework.beans</name>
+                  <name>jboss.osgi.framework.config</name>
                   <value>jboss-osgi-knopflerfish-beans.xml</value>
                 </property>
               </systemProperties>




More information about the jboss-cvs-commits mailing list
--- projects/jboss-osgi/trunk/spi/src/main/java/org/jboss/osgi/spi/internal/MicrocontainerBootstrapProvider.java	2009-04-24 17:35:14 UTC (rev 87823)
+++ projects/jboss-osgi/trunk/spi/src/main/java/org/jboss/osgi/spi/internal/MicrocontainerBootstrapProvider.java	2009-04-24 17:35:41 UTC (rev 87824)
@@ -42,14 +42,14 @@
  */
 public class MicrocontainerBootstrapProvider extends AbstractInstanceProvider implements OSGiBootstrapProvider
 {
-   /** The default framework beans property: org.jboss.osgi.default.framework.beans */
-   public static final String DEFAULT_BOOTSTRAP_BEANS_PROP = "org.jboss.osgi.default.bootstrap.beans";
+   /** The default framework beans property: jboss.osgi.bootstrap.config */
+   public static final String OSGI_BOOTSTRAP_CONFIG = "jboss.osgi.bootstrap.config";
    /** The default framework beans: jboss-osgi-bootstrap-beans.xml */
-   public static final String DEFAULT_BOOTSTRAP_BEANS = "jboss-osgi-bootstrap-beans.xml";
-   /** The default framework beans property: org.jboss.osgi.default.framework.beans */
-   public static final String DEFAULT_FRAMEWORK_BEANS_PROP = "org.jboss.osgi.default.framework.beans";
+   public static final String DEFAULT_OSGI_BOOTSTRAP_XML = "jboss-osgi-bootstrap-beans.xml";
+   /** The default framework beans property: jboss.osgi.framework.config */
+   public static final String OSGI_FRAMEWORK_CONFIG = "jboss.osgi.framework.config";
    /** The default framework beans: jboss-osgi-beans.xml */
-   public static final String DEFAULT_FRAMEWORK_BEANS = "jboss-osgi-beans.xml";
+   public static final String DEFAULT_OSGI_FRAMEWORK_XML = "jboss-osgi-beans.xml";
    
    private EmbeddedBeansDeployer deployer = new EmbeddedBeansDeployer();
    private boolean bootstraped;
@@ -76,12 +76,6 @@
       configureWithDefaultBeans();
    }
 
-   private void configureWithDefaultBeans()
-   {
-      String defaultFrameworkBeans = System.getProperty(DEFAULT_FRAMEWORK_BEANS_PROP, DEFAULT_FRAMEWORK_BEANS);
-      configure(defaultFrameworkBeans);
-   }
-
    public void configure(InputStream streamConfig)
    {
       throw new NotImplementedException("Cannot bootstrap JBossMC from InputStream");
@@ -127,10 +121,16 @@
       return retObj;
    }
 
+   private void configureWithDefaultBeans()
+   {
+      String defaultFrameworkBeans = System.getProperty(OSGI_FRAMEWORK_CONFIG, DEFAULT_OSGI_FRAMEWORK_XML);
+      configure(defaultFrameworkBeans);
+   }
+
    private void bootstrapKernel()
    {
       // Deploy the bootstrap beans if DEFAULT_BOOTSTRAP_BEANS is on the classpath
-      String defaultBootstrapBeans = System.getProperty(DEFAULT_BOOTSTRAP_BEANS_PROP, DEFAULT_BOOTSTRAP_BEANS);
+      String defaultBootstrapBeans = System.getProperty(OSGI_BOOTSTRAP_CONFIG, DEFAULT_OSGI_BOOTSTRAP_XML);
       URL urlBootstrap = Thread.currentThread().getContextClassLoader().getResource(defaultBootstrapBeans);
       if (urlBootstrap != null)
          deployer.deploy(urlBootstrap);

Modified: projects/jboss-osgi/trunk/testsuite/example/pom.xml
===================================================================